@@ -20,10 +20,12 @@ class RecordThree(fixedwidth.Record):
 
 
 class RecordFour(fixedwidth.Record):
-    frag = fields.FragmentWithNewlineField(record=RecordOne)
+    frag = fields.FragmentField(record=RecordOne)
+    new_line = fields.NewLineField()
     other_field = fields.StringField(length=3, default="EEE")
 
 
 class RecordFive(fixedwidth.Record):
-    garf = fields.FragmentWithNewlineField(RecordFour)
+    garf = fields.FragmentField(RecordFour)
+    new_line = fields.NewLineField()
     threeve = fields.ListField(record=RecordThree, length=2)
